diff --git a/dumux/boxmodels/3p3cni/3p3cnivolumevariables.hh b/dumux/boxmodels/3p3cni/3p3cnivolumevariables.hh
index 445e3a29d6e115a2d038fc728c3deff164c5aa6a..c138b8d61a24c79a751354c7fa6c2a06af12dbaf 100644
--- a/dumux/boxmodels/3p3cni/3p3cnivolumevariables.hh
+++ b/dumux/boxmodels/3p3cni/3p3cnivolumevariables.hh
@@ -75,7 +75,7 @@ public:
     void update(const PrimaryVariables &priVars,
                 const Problem &problem,
                 const Element &element,
-                const FVElementGeometry &fvGeomtry,
+                const FVElementGeometry &fvGeometry,
                 const int scvIdx,
                 bool isOldSol)
     {
@@ -83,7 +83,7 @@ public:
         ParentType::update(priVars,
                            problem,
                            element,
-                           fvGeomtry,
+                           fvGeometry,
                            scvIdx,
                            isOldSol);
 
@@ -130,7 +130,7 @@ protected:
     static Scalar temperature_(const PrimaryVariables &primaryVars,
                                const Problem& problem,
                                const Element &element,
-                               const FVElementGeometry &fvGeomtry,
+                               const FVElementGeometry &fvGeometry,
                                const int scvIdx)
     {
         return primaryVars[temperatureIdx];
@@ -142,19 +142,19 @@ protected:
      * \param priVars The solution primary variables
      * \param problem The problem
      * \param element The element
      * \param fvGeomtry Evaluate function with solution of current or previous time step
      * \param scvIdx The local index of the SCV (sub-control volume)
      * \param isOldSol Evaluate function with solution of current or previous time step
      */
     void updateEnergy_(const PrimaryVariables &priVars,
                        const Problem &problem,
                        const Element &element,
-                       const FVElementGeometry &fvGeomtry,
+                       const FVElementGeometry &fvGeometry,
                        const int scvIdx,
                        bool isOldSol)
     {
         // copmute and set the heat capacity of the solid phase
-        heatCapacity_ = problem.spatialParams().heatCapacity(element, fvGeomtry, scvIdx);
+        heatCapacity_ = problem.spatialParams().heatCapacity(element, fvGeometry, scvIdx);
         Valgrind::CheckDefined(heatCapacity_);
     };
@@ -142,19 +142,19 @@ protected:
      * \param problem The problem
      * \param element The element
-     * \param fvGeomtry Evaluate function with solution of current or previous time step
+     * \param fvGeometry Evaluate function with solution of current or previous time step
      * \param scvIdx The local index of the SCV (sub-control volume)
      * \param isOldSol Evaluate function with solution of current or previous time step